pub enum Commands {
Daemon {
workspace: PathBuf,
},
Status,
Refresh,
Symbol {
name: String,
kind: String,
exact: bool,
body: bool,
max_lines: usize,
},
Outline {
file: Option<PathBuf>,
file_list: Option<String>,
output: Option<PathBuf>,
body: bool,
max_lines: usize,
},
Definition {
file: PathBuf,
line: u32,
col: u32,
body: bool,
max_lines: usize,
no_line_numbers: bool,
},
Body {
file: PathBuf,
line: u32,
col: u32,
max_lines: usize,
no_line_numbers: bool,
},
Hover {
file: PathBuf,
line: u32,
col: u32,
},
References {
file: PathBuf,
line: u32,
col: u32,
},
Calls {
file: PathBuf,
line: u32,
col: u32,
direction: CallDirection,
depth: u32,
},
Relations {
file: PathBuf,
line: u32,
col: u32,
mode: RelationMode,
},
InitSkill {
workspace: PathBuf,
dir: Option<PathBuf>,
},
}Variants
Daemon
Start the background LSP daemon and HTTP server
Status
Query daemon and rust-analyzer status
Refresh
Refresh / restart the rust-analyzer session
Symbol
Search workspace symbols
Fields
Outline
Extract file document symbols outline
Fields
Definition
Go to definition at file line and column
Fields
Body
Inspect source code body of struct, function, enum, impl, trait, or module
Fields
Hover
Show documentation and type information at a file position
Fields
References
Find references at a file position
Fields
Calls
Find incoming or outgoing calls at a file position
Fields

direction: CallDirectionCall direction: incoming or outgoing (default: incoming)
Relations
Query Rust symbol relations
Fields

mode: RelationModeRelation mode (currently only implementations)
InitSkill
Initialize/install the rust-codebase-navigation SKILL.md in a workspace