Commands

Enum Commands 

pub enum Commands {
    Daemon {
        workspace: PathBuf,
    },
    Status,
    Refresh,
    Symbol {
        name: String,
        kind: String,
        exact: bool,
        body: bool,
        max_lines: usize,
    },
    Outline {
        file: Option<PathBuf>,
        file_list: Option<String>,
        output: Option<PathBuf>,
        body: bool,
        max_lines: usize,
    },
    Definition {
        file: PathBuf,
        line: u32,
        col: u32,
        body: bool,
        max_lines: usize,
        no_line_numbers: bool,
    },
    Body {
        file: PathBuf,
        line: u32,
        col: u32,
        max_lines: usize,
        no_line_numbers: bool,
    },
    Cursor {
        file: PathBuf,
        line: u32,
        col: u32,
        mode: String,
        depth: u32,
    },
    TypeHierarchy {
        file: PathBuf,
        line: u32,
        col: u32,
        mode: String,
        depth: u32,
    },
    Check {
        target: Option<String>,
    },
    InitSkill {
        workspace: PathBuf,
        dir: Option<PathBuf>,
    },
}

Variants



Daemon

Start the background LSP daemon and HTTP server

Fields

workspace: PathBuf

Workspace root directory



Status

Query daemon and rust-analyzer status



Refresh

Refresh / restart the rust-analyzer session



Symbol

Search workspace symbols

Fields

name: String

Symbol name to search for

kind: String

Optional symbol filter: any, struct, enum, fn, trait, type, const, var

exact: bool

Match exact symbol name

body: bool

Include source code body/snippet

max_lines: usize

Max lines for source code body (0 for unlimited)



Outline

Extract file document symbols outline

Fields

file: Option<PathBuf>

Target file path

file_list: Option<String>

Comma-separated list of target file paths

output: Option<PathBuf>

Write outline output to a file

body: bool

Include source code body/snippet for symbols

max_lines: usize

Max lines for source code body (0 for unlimited)



Definition

Go to definition at file line and column

Fields

file: PathBuf

File path

line: u32

Line number (1-based)

col: u32

Column number (1-based)

body: bool

Include source code body/snippet of the definition target

max_lines: usize

Max lines for source code body (0 for unlimited)

no_line_numbers: bool

Omit line numbers in terminal output



Body

Inspect source code body of struct, function, enum, impl, trait, or module

Fields

file: PathBuf

File path

line: u32

Line number (1-based)

col: u32

Column number (1-based)

max_lines: usize

Max lines for source code body (0 for unlimited)

no_line_numbers: bool

Omit line numbers in terminal output



Cursor

Find references or call hierarchy at file line and column

Fields

file: PathBuf

File path

line: u32

Line number (1-based)

col: u32

Column number (1-based)

mode: String

Mode: incoming, outgoing, or references

depth: u32

Traversal depth (default: 1)



TypeHierarchy

Query type hierarchy (supertypes / subtypes)

Fields

file: PathBuf

File path

line: u32

Line number (1-based)

col: u32

Column number (1-based)

mode: String

Mode: supertypes or subtypes

depth: u32

Traversal depth (default: 1)



Check

Run cargo check compilation verification

Fields

target: Option<String>

Optional cargo build target



InitSkill

Initialize/install the rust-codebase-navigation SKILL.md in a workspace

Fields

workspace: PathBuf

Target workspace directory (default: .)

dir: Option<PathBuf>

Custom relative skill path (default: .agents/skills/rust-codebase-navigation/SKILL.md)